@@ -9,8 +9,29 @@ MCP Server 主程序
 """
 
 import sys
+import os
 from pathlib import Path
 from typing import Optional, List
+import importlib.metadata
+
+# Windows 控制台编码处理
+if sys.platform == 'win32':
+    try:
+        # 设置 stdout 为 UTF-8 编码
+        import io
+        sys.stdout = io.TextIOWrapper(sys.stdout.buffer, encoding='utf-8', errors='replace')
+        sys.stderr = io.TextIOWrapper(sys.stderr.buffer, encoding='utf-8', errors='replace')
+    except Exception:
+        pass  # 忽略编码设置失败
+
+# 尝试导入 TOML 解析库（仅用于开发环境）
+try:
+    if sys.version_info >= (3, 11):
+        import tomllib
+    else:
+        import tomli as tomllib
+except ImportError:
+    tomllib = None
 
 # 添加项目根目录到 Python 路径
 project_root = Path(__file__).parent.parent
@@ -43,6 +64,50 @@ analytics_service = None
 export_service = None
 
 
+def get_version() -> str:
+    """
+    获取包版本号
+    
+    优先使用包元数据，失败时尝试从 pyproject.toml 读取
+    
+    Returns:
+        str: 版本号，读取失败时返回 "1.0.0"
+    """
+    try:
+        # 方法1：从包元数据读取（适用于已安装的包）
+        try:
+            version = importlib.metadata.version("questions-mcp-server")
+            return version
+        except importlib.metadata.PackageNotFoundError:
+            pass
+        
+        # 方法2：从 pyproject.toml 读取（适用于开发环境）
+        possible_paths = [
+            Path(__file__).parent.parent / "pyproject.toml",
+            Path(__file__).parent.parent.parent / "pyproject.toml",
+        ]
+        
+        for pyproject_path in possible_paths:
+            if pyproject_path.exists():
+                # 使用 TOML 库解析
+                if tomllib is not None:
+                    with open(pyproject_path, "rb") as f:
+                        data = tomllib.load(f)
+                        return data.get("project", {}).get("version", "1.0.0")
+                else:
+                    # 降级方案：手动解析 version 行
+                    with open(pyproject_path, "r", encoding="utf-8") as f:
+                        for line in f:
+                            if line.strip().startswith("version"):
+                                # 提取 version = "1.0.3" 中的版本号
+                                version = line.split("=")[1].strip().strip('"').strip("'")
+                                return version
+        
+        return "1.0.0"
+    except Exception:
+        return "1.0.0"
+
+
 def initialize_system():
     """
     初始化系统配置和日志
@@ -56,13 +121,13 @@ def initialize_system():
         # 1. 加载配置
         print("正在加载配置...")
         config = get_config()
-        print(f"✓ 配置加载成功")
+        print("[OK] 配置加载成功")
 
         # 2. 初始化日志系统
         print("正在初始化日志系统...")
         logger = setup_logger(config)
         logger.info("日志系统初始化成功")
-        print(f"✓ 日志系统初始化成功")
+        print("[OK] 日志系统初始化成功")
 
         # 3. 验证关键配置
         logger.info("验证关键配置...")
@@ -71,12 +136,12 @@ def initialize_system():
         logger.info(f"- ChromaDB Collection 名称: {config.chromadb_collection_name}")
         logger.info(f"- Embedding API 端点: {config.embedding_api_endpoint}")
         logger.info(f"- 日志级别: {config.log_level}")
-        print(f"✓ 配置验证完成")
+        print("[OK] 配置验证完成")
 
         return config, logger
 
     except Exception as e:
-        print(f"✗ 系统初始化失败: {e}")
+        print(f"[ERROR] 系统初始化失败: {e}")
         sys.exit(1)
 
 
@@ -96,7 +161,7 @@ def create_mcp_server(config, logger):
             version=config.get("server.version", "1.0.0"),
         )
 
-        logger.info("✓ FastMCP Server 创建成功")
+        logger.info("[OK] FastMCP Server 创建成功")
         return server
 
     except Exception as e:
@@ -187,7 +252,7 @@ def initialize_services(config, logger):
             logger=logger
         )
 
-        logger.info("✓ 所有服务初始化完成")
+        logger.info("[OK] 所有服务初始化完成")
         return db_manager, management_service, search_service, import_service, analytics_service, export_service
 
     except Exception as e:
@@ -1321,7 +1386,7 @@ def register_tools(server: FastMCP, config, logger):
                 "timestamp": from_src_utils_import_get_current_timestamp(),
             }
 
-    logger.info(f"✓ 已注册 MCP Tools")
+    logger.info(f"[OK] 已注册 MCP Tools")
 
 
 def from_src_utils_import_Optional_and_List():
@@ -1347,7 +1412,7 @@ def main():
 
     print("=" * 60)
     print("Questions MCP Server - 题目管理与检索系统")
-    print("Version: 1.0.0")
+    print(f"Version: {get_version()}")
     print("=" * 60)
     print()
 
@@ -1360,19 +1425,19 @@ def main():
         # 2. 创建 MCP Server
         print("阶段 2: 创建 MCP Server...")
         mcp_server = create_mcp_server(config, logger)
-        print("✓ MCP Server 创建成功")
+        print("[OK] MCP Server 创建成功")
         print()
 
         # 3. 初始化服务
         print("阶段3: 初始化服务...")
         db_manager, management_service, search_service, import_service, analytics_service, export_service = initialize_services(config, logger)
-        print("✓ 服务初始化完成")
+        print("[OK] 服务初始化完成")
         print()
 
         # 4. 注册 Tools
         print("阶段 4: 注册 MCP Tools...")
         register_tools(mcp_server, config, logger)
-        print("✓ Tools 注册完成")
+        print("[OK] Tools 注册完成")
         print()
 
         # 5. 注册信号处理器（用于优雅关闭）
@@ -1401,7 +1466,7 @@ def main():
 
         # 6. 启动服务器
         print("=" * 60)
-        print("✓ Questions MCP Server 启动成功!")
+        print("[OK] Questions MCP Server 启动成功!")
         print("=" * 60)
         logger.info("Questions MCP Server 启动成功")
         logger.info("服务器正在运行，等待客户端连接...")
@@ -1418,7 +1483,7 @@ def main():
         if logger:
             logger.info("收到中断信号，正在关闭服务器...")
     except Exception as e:
-        print(f"\n✗ 启动失败: {e}")
+        print(f"\n[ERROR] 启动失败: {e}")
         if logger:
             logger.error(f"服务器启动失败: {e}")
         sys.exit(1)
